import os
import re
import glob
import subprocess
from IPython.display import Javascript


here = os.getcwd()


def native_cmd(cmd, whitespace=False):
    """Returns the output of a native command on a give system.

    NOTE: Results may contain white space charaters at end of lines.
    """
    result = subprocess.check_output(cmd, shell=True).decode()
    if whitespace:
        return result
    else:
        # Remove carrige returns.
        result = re.sub('\r|\n', '', result, re.X)
        return result

# Javascript for notebook_save.
notebook_save_script = '''
require(["base/js/namespace"],function(Jupyter) {
    Jupyter.notebook.save_checkpoint();
});
'''


def notebook_save():
    Javascript(notebook_save_script)
    print('This notebook has been saved.')


def notebook_current():
    ipynb_list = list(map(lambda x: (x, os.path.getmtime(x)),
                          glob.glob("*.ipynb")))

    ipynb_list.sort(key=lambda x: x[1], reverse=True)
    last_modified = ipynb_list[0][0]
    return last_modified


def nbconvert_wrapper(file_type=None, file_name=None):
    command = "jupyter nbconvert --to {file_type} {file_name}".format(**locals())
    result = native_cmd(command)
    return result


def notebook_current_convert(file_type=None):
    notebook_save()
    result = nbconvert_wrapper(file_type=file_type, file_name=notebook_current())
    if len(result) == 0:
        print("Converted notebook.")
    else:
        print("Failed to convert notebook.")
    return



"""A setuptools based setup module.

See:
https://packaging.python.org/en/latest/distributing.html
https://github.com/pypa/sampleproject
"""

from setuptools import setup, find_packages
from os import path

here = path.abspath(path.dirname(__file__))

setup(
    name='guipyter',

    # Versions should comply with PEP440.  For a discussion on single-sourcing
    # the version across setup.py and the project code, see
    # https://packaging.python.org/en/latest/single_source_version.html
    version='0.0.2',

    description="GUI tools for jupyter notebook.",
    # The project's main homepage.
    url='https://github.com/draperjames/guipyter',

    # Author details
    author='James Draper',
    author_email='james.draper@duke.edu',

    # Choose your license
    license='MIT',

    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 3 - Alpha',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: MIT License',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],

    # What does your project relate to?
    keywords='Jupyter Notebook',

    # You can just specify the packages manually here if your project is
    # simple. Or you can use find_packages().
    packages=find_packages(),

    # List run-time dependencies here.  These will be installed by pip when
    # your project is installed. For an analysis of "install_requires" vs pip's
    # requirements files see:
    # https://packaging.python.org/en/latest/requirements.html
    #install_requires=['peppercorn'],


    # To provide executable scripts, use entry points in preference to the
    # "scripts" keyword. Entry points provide cross-platform support and allow
    # pip to create the appropriate form of executable for the target platform.
    # entry_points={
    #     'console_scripts': [
    #         'guipyter=guipyter:main'
    #         #'sample=sample:main',
    #     ],
    # },
)
